function [Amplitude, AoverD, STD, frequencyOsc, t, mintab, maxtab] = computeRealAstarAndTimeHistory(realSpringTestData, TickProcessOptions)
% Processes the time history data of the 1st cylinder from an csv file and outputs 
% A/D, displacement-time history, STD(A/D), Oscillation Frequency and
% recorded time vector
% Run==> Select file ==>  result
% It should combine the peakdet.m file together
% By Hai Sun, July 1st,2014. Edited by Mert Turkol, 02/03/2015

PositionTicks = realSpringTestData{3};
Mean = mean(PositionTicks);
PositionTicks = PositionTicks - Mean;

% A/D
sampleRate = TickProcessOptions.realSpringSampleRate;
minThresholdAmplitude = TickProcessOptions.minThresholdAmplitude;
numAllowedPeaks = TickProcessOptions.numPeaksToCount;

AoverD = PositionTicks;
%% Low-pass filter application
% AoverD is the signal that should be passed to the filter as arguement

B = [0.00460112  0.00690758  0.01304982  0.02337257  0.0374197 0.05394049 ...
    0.07105863 0.08657665  0.09835848 0.10471498 0.10471498  0.09835848 ...
    0.08657665  0.07105863 0.05394049 0.0374197   0.02337257  0.01304982...
    0.00690758  0.00460112];

AoverD = filtfilt(B,[1], AoverD);

ticks = numel(AoverD);
tMax = sampleRate*ticks; tMiddle = tMax/ticks; t = sampleRate:tMiddle:tMax; t = t';
%% Find the max and min amplitude in A/D
[maxtab, mintab] = peakdet(AoverD, minThresholdAmplitude, t);
lastMax = length(maxtab)-1;
lastMin = length(mintab)-1;
% delete the first and last max and min
maxtab = maxtab( 2:lastMax , : );
mintab = mintab( 2:lastMin , : );

% find the A/D by plus the max and min over 2
    sortedAllMaxPeaks = sort(maxtab(:,2),'descend');
    sortedAllMinPeaks = sort(mintab(:,2),'descend');
    
    numMaxPeaks = min(numAllowedPeaks,length(sortedAllMaxPeaks));
    numMinPeaks = min(numAllowedPeaks,length(sortedAllMinPeaks));
    
    maxPeaks = sortedAllMaxPeaks(1:numMaxPeaks);
    minPeaks = sortedAllMinPeaks(1:numMinPeaks);
    meanMax = mean(maxPeaks);
    meanMin = mean(minPeaks);
    Amplitude = (abs(meanMax)+abs(meanMin))/2;


    STDmax = std(maxPeaks);
    STDmin = std(minPeaks);

    STD = (STDmax+STDmin)/2;

% calculate the Frequency of Cylinder Oscillation
tempMax = maxtab(:,1)';
tempMin = mintab(:,1)';
timeIntervalMax = tempMax(lastMax-1)-tempMax(1);
timeIntervalMin = tempMin(lastMin-1)-tempMin(1);
frequencyOsc = ((lastMax/timeIntervalMax)+(lastMin/timeIntervalMin))/2;
end
