function [Amplitude, AoverD, STD, frequencyOsc, t, mintab, maxtab] = computeVCKAstarAndTimeHistory(vckTestData, TickProcessOptions)
% Processes the time history data of the 2nd cylinder from an csv file and outputs 
% A/D, displacement-time history, STD(A/D), Oscillation Frequency and recorded
% time vector
% Run==> Select file ==>  result
% It should combine the peakdet.m file together
% By Hai Sun, July 1st,2014. Edited by Mert Turkol, 02/03/2015

PositionTicks = vckTestData{1};
Mean = mean(PositionTicks);
PositionTicks=PositionTicks - Mean;

% A/D
sampleRate = TickProcessOptions.VCKsampleRate;
minThresholdAmplitude = TickProcessOptions.minThresholdAmplitude;
numAllowedPeaks = TickProcessOptions.numPeaksToCount;
% max seconds to allow no peak behavior to appear in oscillations
peakDetectTime = TickProcessOptions.peakDetectTimeThreshold; 

AoverD = PositionTicks.*0.9144./22684./0.0889;
ticks = numel(AoverD);
tMax = sampleRate*ticks; tMiddle = tMax/ticks; t = sampleRate:tMiddle:tMax; t=t';
%% Find the max and min amplitude in A/D
[maxtab, mintab] = peakdet(AoverD, minThresholdAmplitude, t);
% check for constant very low amplitude to eliminate non-useful data
if (max(diff(maxtab(:,1))) < peakDetectTime && ...
    max(diff(mintab(:,1))) < peakDetectTime) 
    %when oscillation data has valid peaks within detection threshold

    lastMax = length(maxtab)-1;
    lastMin = length(mintab)-1;
    %delete the first and last max and min
    maxtab = maxtab( 2:lastMax , : );
    mintab = mintab( 2:lastMin , : );


    % find the A/D by plus the max and min over 2
    sortedAllMaxPeaks = sort(maxtab(:,2),'descend');
    sortedAllMinPeaks = sort(mintab(:,2),'descend');
    
    numMaxPeaks = min(numAllowedPeaks,length(sortedAllMaxPeaks));
    numMinPeaks = min(numAllowedPeaks,length(sortedAllMinPeaks));
    
    maxPeaks = sortedAllMaxPeaks(1:numMaxPeaks);
    minPeaks = sortedAllMinPeaks(1:numMinPeaks);
    meanMax = mean(maxPeaks);
    meanMin = mean(minPeaks);
    Amplitude = (abs(meanMax)+abs(meanMin))/2;


    STDmax = std(maxPeaks);
    STDmin = std(minPeaks);
    STD = (STDmax+STDmin)/2;

    % calculate the Frequency of Cylinder Oscillation
    tempMax = maxtab(:,1)';
    tempMin = mintab(:,1)';
    timeIntervalMax = tempMax(lastMax-1)-tempMax(1);
    timeIntervalMin = tempMin(lastMin-1)-tempMin(1);
    frequencyOsc = ((lastMax/timeIntervalMax)+(lastMin/timeIntervalMin))/2;
else %when oscillation data has NO valid peaks within detection threshold

    Amplitude = 0; STD = 0; frequencyOsc = 0;
end
end
